package com.example.myapplication.user.composeui

import android.content.res.Configuration
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.example.myapplication.user.model.getTestUser
import com.example.myapplication.ui.theme.MyApplicationTheme
import com.example.myapplication.R

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun UserView(id: Int) {
    var user = getTestUser()[id]
    Column(
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier
            .padding(all = 10.dp)
            .verticalScroll(rememberScrollState())) {
        OutlinedTextField(modifier = Modifier.fillMaxWidth(), value = user.login, onValueChange = {}, readOnly = true,
            label = {
                Text(stringResource(id = R.string.user_login))
            }
        )
        OutlinedTextField(modifier = Modifier.fillMaxWidth(), value = user.fio, onValueChange = {}, readOnly = true,
            label = {
                Text(stringResource(id = R.string.user_fio))
            }
        )
        user.challenges.forEachIndexed() { _, challenge ->
            Row {
                Text(text = challenge.challenge_name)
                if (challenge.challenge_status) {
                    Text(text = " - Выполнено")
                }
                else {
                    Text(text = " - В процессе")
                }
            }
        }
    }
}

@Preview(name = "Light Mode", showBackground = true, uiMode = Configuration.UI_MODE_NIGHT_NO)
@Preview(name = "Dark Mode", showBackground = true, uiMode = Configuration.UI_MODE_NIGHT_YES)
@Composable
fun PerformanceViewPreview() {
    MyApplicationTheme {
        Surface(
            color = MaterialTheme.colorScheme.background
        ) {
            UserView(id = 0)
        }
    }
}
